@@ -28,6 +28,9 @@ test_data_dir = os.path.join(os.path.dirname(__file__), 'data', 'package')
 
 class PackageTest(unittest.TestCase):
 
+    if sys.version_info[0] == 2:
+        assertRaisesRegex = unittest.TestCase.assertRaisesRegexp
+
     def get_maintainer(self):
         maint = Mock()
         maint.email = 'foo@bar.com'
@@ -52,7 +55,7 @@ class PackageTest(unittest.TestCase):
         self.assertEqual([], pack.authors)
         self.assertEqual([maint], pack.maintainers)
         self.assertEqual(['BSD'], pack.licenses)
-        self.assertEqual([None], [l.file for l in pack.licenses])
+        self.assertEqual([None], [license_.file for license_ in pack.licenses])
         self.assertEqual([], pack.build_depends)
         self.assertEqual([], pack.buildtool_depends)
         self.assertEqual([], pack.run_depends)
@@ -118,6 +121,31 @@ class PackageTest(unittest.TestCase):
         dep = Dependency('foo', condition='foo <= bar or bar >= baz')
         self.assertFalse(dep.evaluate_condition({}))
 
+        # Testing for more than 1 conditions
+        dep = Dependency('foo', condition='foo > bar and bar < baz and foo > bar')
+        self.assertTrue(dep.evaluate_condition({}))
+
+        dep = Dependency('foo', condition='foo <= bar and bar >= baz and foo > bar')
+        self.assertFalse(dep.evaluate_condition({}))
+
+        dep = Dependency('foo', condition='foo > bar or bar < baz or foo <= bar')
+        self.assertTrue(dep.evaluate_condition({}))
+
+        dep = Dependency('foo', condition='foo <= bar or bar >= baz or foo <= bar')
+        self.assertFalse(dep.evaluate_condition({}))
+
+        dep = Dependency('foo', condition='foo <= bar and bar < baz or foo > bar')
+        self.assertTrue(dep.evaluate_condition({}))
+
+        dep = Dependency('foo', condition='foo <= bar or bar < baz and foo < bar')
+        self.assertFalse(dep.evaluate_condition({}))
+
+        dep = Dependency('foo', condition='foo > bar and bar >= baz or foo > bar')
+        self.assertTrue(dep.evaluate_condition({}))
+
+        dep = Dependency('foo', condition='foo <= bar or bar >= baz and foo < bar')
+        self.assertFalse(dep.evaluate_condition({}))
+
     def test_dependency_repr(self):
         dep = Dependency('foo', condition='$foo == 2')
         assert repr(dep) == "Dependency(name='foo', condition='$foo == 2')"
@@ -176,7 +204,7 @@ class PackageTest(unittest.TestCase):
                        exports=mexp)
         self.assertEqual(mmain, pack.maintainers)
         self.assertEqual(mlis, pack.licenses)
-        self.assertEqual([None, 'LICENSE'], [l.file for l in pack.licenses])
+        self.assertEqual([None, 'LICENSE'], [license_.file for license_ in pack.licenses])
         self.assertEqual(murl, pack.urls)
         self.assertEqual(mauth, pack.authors)
         self.assertEqual(mbuilddep, pack.build_depends)
@@ -296,7 +324,7 @@ class PackageTest(unittest.TestCase):
         except Exception as e:
             self.fail('create_node() raised %s "%s" unexpectedly!' % (type(e), str(e)))
 
-        self.assertRaisesRegexp(Exception, 'unbound prefix: line 1, column 0', create_node, 'tag', {'ns:key': 'value'})
+        self.assertRaisesRegex(Exception, 'unbound prefix: line 1, column 0', create_node, 'tag', {'ns:key': 'value'})
 
         try:
             create_node('tag', {'ns:key': 'value', 'xmlns:ns': 'urn:ns'})
